/*
** console.h
** 
** Made by kulakov Kirill
** Login   <kulakov@seeker-netbook>
** 
** Started on  Fri Jan 29 16:11:32 2010 kulakov Kirill
** Last update Fri Feb  5 13:00:47 2010 kulakov Kirill
*/

#ifndef   	CONSOLE_H_
# define   	CONSOLE_H_

#include "mysocials_driver.h"

#define MODULE_INIT "msa_module_init"

#define GETTEXT_PACKAGE "mysocials_console"
#define LOCALEDIR "./po"

extern gchar *command_file;
extern gchar *progname;
extern gchar *driver;
extern struct msa_module *driver_module;
extern gchar *log_file;
extern FILE *stdlog;

#endif 	    /* !CONSOLE_H_ */
